# ../scripts/custom/gg_nocash/gg_nocash.py

# ============================================================================
# >> IMPORTS
# ============================================================================
# EventScripts Imports
#   ES
from es import getUseridList
from es import ServerVar
#   Gamethread
from gamethread import delayed

# SPE Imports
from spe import detourFunction
from spe import getIndexOfEntity
from spe import HookAction
from spe import HookType
from spe import undetourFunction

# SPE Tools Imports
#   Player
from spe.tools.player import SPEPlayer

# GunGame Imports
#   Addons
from gungame51.core.addons.shortcuts import AddonInfo

# ============================================================================
# >> ADDON REGISTRATION/INFORMATION
# ============================================================================
info = AddonInfo()
info.name = 'gg_nocash'
info.title = 'GG NoCash' 
info.author = 'Satoon101' 
info.version = '2.3'

# =============================================================================
# >> PUBLIC VARIABLE
# =============================================================================
ServerVar(info.name + '_version', info.version,
        info.title + ' Version').set(info.version)
ServerVar(info.name + '_version').makepublic()


# ============================================================================
# >> LOAD & UNLOAD
# ============================================================================
def load():
    '''Called when the script is loaded'''

    # Detour CCSPlayer::AddAccount
    detourFunction('AddAccount', HookType.Pre, cash_callback)

    # Loop through all players on the server
    for userid in getUseridList():

        SPEPlayer(userid).cash = 0


def unload():
    '''Called when the script is unloaded'''

    # Undetour CCSPlayer::AddAccount
    undetourFunction('AddAccount', HookType.Pre, cash_callback)


# ============================================================================
# >> DETOUR CALLBACKS
# ============================================================================
def cash_callback(args):
    '''Called when a player is recieving money'''

    # Delay 1 tick, then reset the player's cash
    delayed(0, reset_cash, args[2])

    # Allow the function to continue
    return (HookAction.Continue, 0)


# =============================================================================
# >> DELAY CALLS
# =============================================================================
def reset_cash(pointer):
    '''Resets a player's cash to 0'''

    # Get the player's index
    index = getIndexOfEntity(pointer)

    # Is the player still on the server?
    if not index:

        # If not, return
        return

    # Get the player's SPEPlayer instance
    player = SPEPlayer.get_instance_from_index(index)

    # Set the player's cash to 0
    player.cash = 0
